==> mlearner-0.1.1.tar.gz: mlearner-0.1.1/README.md <==

![Carpeta](./docs/sources/img/Carpeta.PNG)

---
# MLearner: Machine Learning for Data Engineer
<br>


[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)

[![made-for-VSCode](https://img.shields.io/badge/Made%20for-VSCode-1f425f.svg)](https://code.visualstudio.com/)
![Python](https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8-blue)
[![GitHub release](https://img.shields.io/github/release/jaisenbe58r/MLearner.svg)](https://GitHub.com/jaisenbe58r/MLearner/releases/)
[![GitHub commits](https://img.shields.io/github/commits-since/jaisenbe58r/MLearner/v0.0.5.svg)](https://GitHub.com/jaisenbe58r/MLearner/commit/)
[![PyPI Latest Release](https://badge.fury.io/py/matplotlib.svg)](https://pypi.org/project/mlearner/)
[![Build status](https://ci.appveyor.com/api/projects/status/7vx20e0h5dxcyla2/branch/master?svg=true)](https://ci.appveyor.com/project/jaisenbe58r/MLearner/branch/master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/68209df46c8240b887db5ae5fa3cb410)](https://www.codacy.com/manual/jaisenbe58r/MLearner?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=jaisenbe58r/MLearner&amp;utm_campaign=Badge_Grade)
[![Build Status](https://travis-ci.org/jaisenbe58r/MLearner.svg?branch=master)](https://travis-ci.org/jaisenbe58r/MLearner)
[![codecov](https://codecov.io/gh/jaisenbe58r/MLearner/branch/master/graph/badge.svg)](https://codecov.io/gh/jaisenbe58r/MLearner)
[![Coverage Status](https://coveralls.io/repos/github/jaisenbe58r/MLearner/badge.svg?branch=master)](https://coveralls.io/github/jaisenbe58r/MLearner?branch=master)
[![License](https://img.shields.io/badge/license-MIT-ORANGE.svg)](https://github.com/jaisenbe58r/MLearner/blob/master/LICENSE)
[![Documentation Status](https://readthedocs.org/projects/ansicolortags/badge/?version=latest)](http://ansicolortags.readthedocs.io/?badge=latest)
[![DOI](https://zenodo.org/badge/256283484.svg)](https://zenodo.org/badge/latestdoi/256283484)
[![GitHub contributors](https://img.shields.io/github/contributors/jaisenbe58r/MLearner.svg)](https://GitHub.com/jaisenbe58r/MLearner/graphs/contributors/)
[![GitHub issues](https://img.shields.io/github/issues/jaisenbe58r/MLearner.svg)](https://GitHub.com/jaisenbe58r/MLearner/issues/)
[![Discuss](https://img.shields.io/badge/discuss-DISCORD-PURPLE.svg)](https://discord.gg/HUxahg)
[![GitHubIssues](https://img.shields.io/badge/issue_tracking-github-violet.svg)](https://github.com/jaisenbe58r/MLearner/issues)
[![saythanks](https://img.shields.io/badge/say-thanks-ff69b4.svg)](https://saythanks.io/to/kennethreitz)





**MLearner is a Python library of useful tools for the day-to-day data science tasks.**



Jaime Sendra Berenguer - Spain - 2020
[![Linkedin](https://i.stack.imgur.com/gVE0j.png) LinkedIn](www.linkedin.com/in/jaisenbe)
[![GitHub](https://i.stack.imgur.com/tskMh.png) GitHub](https://github.com/jaisenbe58r)



<br>

## Links

- **Documentation:** [https://jaisenbe58r.github.io/MLearner/](https://jaisenbe58r.github.io/MLearner/)
- PyPI: [https://pypi.python.org/pypi/mlearner](https://pypi.python.org/pypi/mlearner)
- Changelog: [https://jaisenbe58r.github.io/MLearner//CHANGELOG](https://jaisenbe58r.github.io/MLearner//CHANGELOG)
- Contributing: [https://jaisenbe58r.github.io/MLearner//CONTRIBUTING](https://jaisenbe58r.github.io/MLearner//CONTRIBUTING)
- Questions? Check out the [Google Groups mailing list](https://groups.google.com/forum/#!forum/mlearner)

<br>
<br>

## Installing mlearner

#### PyPI

To install mlearner, just execute  

```bash
pip install mlearner  
```

Alternatively, you could download the package manually from the Python Package Index [https://pypi.python.org/pypi/mlearner](https://pypi.python.org/pypi/mlearner), unzip it, navigate into the package, and use the command:

```bash
python setup.py install
```

#### Conda
If you use conda, to install mlearner just execute

```bash
conda install -c conda-forge mlearner 
```

#### Dev Version

The mlearner version on PyPI may always be one step behind; you can install the latest development version from the GitHub repository by executing

```bash
pip install git+git://github.com/jaisenbe58r/MLearner.git#egg=mlearner
```

Or, you can fork the GitHub repository from https://github.com/jaisenbe58r/MLearner and install mlearner from your local drive via

```bash
python setup.py install
```


---

## License


## Contact

==> mlearner-0.1.3.dev0.tar.gz: mlearner-0.1.3.dev0/README.md <==

![Carpeta](./docs/sources/img/Carpeta.PNG)

---
# MLearner: Machine Learning for Data Engineer
<br>


[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)

[![made-for-VSCode](https://img.shields.io/badge/Made%20for-VSCode-1f425f.svg)](https://code.visualstudio.com/)
![Python](https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8-blue)
[![GitHub release](https://img.shields.io/github/release/jaisenbe58r/MLearner.svg)](https://GitHub.com/jaisenbe58r/MLearner/releases/)
[![GitHub commits](https://img.shields.io/github/commits-since/jaisenbe58r/MLearner/v0.1.1.svg)](https://GitHub.com/jaisenbe58r/MLearner/commit/)
[![PyPI Latest Release](https://badge.fury.io/py/mlearner.svg)](https://pypi.org/project/mlearner/)
[![Build status](https://ci.appveyor.com/api/projects/status/7vx20e0h5dxcyla2/branch/master?svg=true)](https://ci.appveyor.com/project/jaisenbe58r/MLearner/branch/master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/2f5b0302acc04a3dac74d6815fdf66e5)](https://www.codacy.com/manual/jaisenbe58r/MLearner?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=jaisenbe58r/MLearner&amp;utm_campaign=Badge_Grade)
[![Build Status](https://travis-ci.org/jaisenbe58r/MLearner.svg?branch=master)](https://travis-ci.org/jaisenbe58r/MLearner)
[![codecov](https://codecov.io/gh/jaisenbe58r/MLearner/branch/master/graph/badge.svg)](https://codecov.io/gh/jaisenbe58r/MLearner)
[![License](https://img.shields.io/badge/license-MIT-ORANGE.svg)](https://github.com/jaisenbe58r/MLearner/blob/master/LICENSE)
[![Documentation Status](https://readthedocs.org/projects/ansicolortags/badge/?version=latest)](http://ansicolortags.readthedocs.io/?badge=latest)
[![DOI](https://zenodo.org/badge/256283484.svg)](https://zenodo.org/badge/latestdoi/256283484)
[![GitHub contributors](https://img.shields.io/github/contributors/jaisenbe58r/MLearner.svg)](https://GitHub.com/jaisenbe58r/MLearner/graphs/contributors/)
[![GitHub issues](https://img.shields.io/github/issues/jaisenbe58r/MLearner.svg)](https://GitHub.com/jaisenbe58r/MLearner/issues/)
[![Discuss](https://img.shields.io/badge/discuss-DISCORD-PURPLE.svg)](https://discord.gg/HUxahg)
[![GitHubIssues](https://img.shields.io/badge/issue_tracking-github-violet.svg)](https://github.com/jaisenbe58r/MLearner/issues)
[![saythanks](https://img.shields.io/badge/say-thanks-ff69b4.svg)](https://saythanks.io/to/kennethreitz)





**MLearner is a Python library of useful tools for the day-to-day data science tasks.**



Jaime Sendra Berenguer - Spain - 2020
[![Linkedin](https://i.stack.imgur.com/gVE0j.png) LinkedIn](https://linkedin.com/in/jaisenbe)
[![GitHub](https://i.stack.imgur.com/tskMh.png) GitHub](https://github.com/jaisenbe58r)



<br>

## Links


- **Documentation:** [https://jaisenbe58r.github.io/MLearner/](https://jaisenbe58r.github.io/MLearner/)
- PyPI: [https://pypi.python.org/pypi/mlearner](https://pypi.python.org/pypi/mlearner)
- Changelog: [https://jaisenbe58r.github.io/MLearner//CHANGELOG](https://jaisenbe58r.github.io/MLearner//CHANGELOG)
- Contributing: [https://jaisenbe58r.github.io/MLearner//CONTRIBUTING](https://jaisenbe58r.github.io/MLearner//CONTRIBUTING)
- Questions? Check out the [Discuss](https://discord.gg/HUxahg)

<br>
<br>

## Installing mlearner

#### PyPI

To install mlearner, just execute  

```bash
pip install mlearner  
```

Alternatively, you could download the package manually from the Python Package Index [https://pypi.python.org/pypi/mlearner](https://pypi.python.org/pypi/mlearner), unzip it, navigate into the package, and use the command:

```bash
python setup.py install
```

#### Conda
If you use conda, to install mlearner just execute

```bash
conda install -c conda-forge mlearner 
```

#### Dev Version

The mlearner version on PyPI may always be one step behind; you can install the latest development version from the GitHub repository by executing

```bash
pip install git+git://github.com/jaisenbe58r/MLearner.git#egg=mlearner
```

Or, you can fork the GitHub repository from https://github.com/jaisenbe58r/MLearner and install mlearner from your local drive via

```bash
python setup.py install
```


---

## License


## Contact
